@@ -27,8 +27,41 @@ from abc import ABCMeta, abstractmethod, abstractproperty
 from six import add_metaclass, string_types
 
 
-def _as_iterable(iterable_or_scalar):
-    if isinstance(iterable_or_scalar, string_types):
+def as_iterable(iterable_or_scalar):
+    """Utility for converting an object to an iterable.
+
+    Parameters
+    ----------
+    iterable_or_scalar : anything
+
+    Returns
+    -------
+    l : iterable
+        If `obj` was None, return the empty tuple.
+        If `obj` was not iterable returns a 1-tuple containing `obj`.
+        Otherwise return `obj`
+
+    Notes
+    -----
+    Although both string types and dictionaries are iterable in Python, we are treating them as not iterable in this
+    method.  Thus, as_iterable(dict()) returns (dict, ) and as_iterable(string) returns (string, )
+
+    Exammples
+    ---------
+    >>> as_iterable(1)
+    (1,)
+    >>> as_iterable([1, 2, 3])
+    [1, 2, 3]
+    >>> as_iterable("my string")
+    ("my string", )
+    >>> as_iterable({'a': 1})
+    ({'a': 1}, )
+
+    """
+
+    if iterable_or_scalar is None:
+        return ()
+    elif isinstance(iterable_or_scalar, string_types):
         return (iterable_or_scalar,)
     elif hasattr(iterable_or_scalar, "__iter__"):
         return iterable_or_scalar
@@ -110,7 +143,7 @@ class JVMHelpers(object):
     def to_scala_seq(self, list_like):
         """Converts a python list-like object to a scala.collection.immutable.Seq.
         """
-        l = _as_iterable(list_like)
+        l = as_iterable(list_like)
         converters = self.import_scala_object("scala.collection.JavaConverters")
         # Since py4j already converts a python list to a Java.util.List<> we can make use of the
         # scala converters
@@ -129,10 +162,27 @@ class JVMHelpers(object):
         """
         return self.to_scala_seq(list_like).toList()
 
-    def to_scala_array(self, list_like):
+    def get_classtag(self, java_class_name):
+        jclassTagO = self.import_scala_object("scala.reflect.ClassTag")
+        klass = self.classloader.loadClass(java_class_name)
+        return jclassTagO.apply(klass)
+
+    def to_scala_array(self, list_like, java_class_name):
         """Converts a python list-like to a a scala Array
+
+        Parameters
+        ----------
+        list_like : list
+        java_class_name : str
+            Java class name to use for the conversion
+
+        Examples
+        >>> c.to_scala_array([1,2,3,4], "java.lang.Integer")
+        ...
+
         """
-        return self.to_scala_seq(list_like).toArray()
+        jseq = self.to_scala_seq(list_like)
+        return jseq.toArray(self.get_classtag(java_class_name))
 
     def to_scala_set(self, set_like):
         """Converts a python set-like to a scala.collection.Set
