@@ -39,6 +39,7 @@ __author__ = 'mniekerk'
 
 log = logging.getLogger("spylon.spark.yarn_launcher")
 
+
 def create_conda_env(sandbox_dir, env_name, dependencies, options=()):
     """
     Create a conda environment inside the current sandbox for the given list of dependencies and options.
@@ -85,6 +86,7 @@ def archive_dir(env_dir):
     subprocess.check_call(["zip", "-r", "-0", "-q", output_filename, env_dir])
     return output_filename
 
+
 #TODO : move this into the SparkConfiguration object
 def prepare_pyspark_yarn_interactive(env_name, env_archive, spark_conf):
     """
@@ -102,7 +104,6 @@ def prepare_pyspark_yarn_interactive(env_name, env_archive, spark_conf):
     >>> conf = SparkConfiguration()
     >>> import spylon.spark.yarn_launcher as yl
     >>> conf = yl.prepare_pyspark_yarn_interactive(
-    ...    env_dir="",
     ...    env_name="yarn-pyspark-env", env_archive="hdfs:///path/to/conda_envs/yarn-pyspark-env.zip",
     ...    spark_conf=conf
     ... )
@@ -150,7 +151,8 @@ def prepare_pyspark_yarn_interactive(env_name, env_archive, spark_conf):
 
 def run_pyspark_yarn_client(env_dir, env_name, env_archive, args):
     """
-    Initializes the requires spark command line options on order to start a python job with the given python environment.
+    Initializes the requires spark command line options on order to start a python job with the given python
+    environment.
 
     Parameters
     ----------
